@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "E. Papillon, V.A. Sole - ESRF Software Group"
+__author__ = "E. Papillon, V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -306,7 +306,12 @@ class QEdfFileWidget(qt.QWidget):
             self.applygroupLayout.addWidget(self.applytoone)
             self.applygroupLayout.addWidget(self.applytoall)
             self.__dummyW.layout.addWidget(self.applygroupContainer)
-            self.applygroup.buttonClicked[int].connect(self.groupSignal)
+            if hasattr(self.applygroup, "idClicked"):
+                self.applygroup.idClicked[int].connect(self.groupSignal)
+            else:
+                # deprecated
+                _logger.debug("Using deprecated signal")
+                self.applygroup.buttonClicked[int].connect(self.groupSignal)
 
         self.dataInfoWidgetDict = {}
         self.paramWidget = EdfFile_StandardArray(self.__dummyW)
@@ -516,7 +521,7 @@ class QEdfFileWidget(qt.QWidget):
         outfile.setFileMode(outfile.AnyFile)
         outfile.setAcceptMode(outfile.AcceptSave)
         outfile.setDirectory(self.lastInputDir)
-        ret = outfile.exec_()
+        ret = outfile.exec()
 
         if not ret:
             return
@@ -850,7 +855,7 @@ class QEdfFileWidget(qt.QWidget):
                 strlist.append("All Files *")
                 fdialog.setFilters(strlist)
                 fdialog.setFileMode(fdialog.ExistingFiles)
-                ret = fdialog.exec_()
+                ret = fdialog.exec()
                 if ret == qt.QDialog.Accepted:
                     filelist = fdialog.selectedFiles()
                     fdialog.close()
@@ -1716,7 +1721,7 @@ def test2():
 
     w = EdfFile_StandardArray()
     w.show()
-    a.exec_()
+    a.exec()
 
 def test():
     import sys
@@ -1750,7 +1755,7 @@ def test():
     w.sigReplaceSelection.connect(replaceSelection)
     w.show()
     if a is not None:
-        a.exec_()
+        a.exec()
     else:
         return w
 
