@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 V.A. Sole, ESRF - D. Dale CHESS
+# Copyright (C) 2004-2021 V.A. Sole, ESRF - D. Dale CHESS
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -312,6 +312,8 @@ class H5NodeProxy(object):
     def shape(self):
         if type(self._shape) == type(""):
             return self._shape
+        if self._shape is None:
+            return ""
         if len(self._shape) == 1:
             return "%d" % self._shape[0]
         elif len(self._shape) > 1:
@@ -825,7 +827,7 @@ class HDF5Widget(FileView):
         ddict['dtype'] = item.dtype
         ddict['shape'] = item.shape
         ddict['color'] = item.color
-        ddict['mouse'] = self._lastMouse * 1
+        ddict['mouse'] = getattr(self, '_lastMouse', 'left') * 1
         self.sigHDF5WidgetSignal.emit(ddict)
 
     def getSelectedEntries(self):
@@ -985,7 +987,7 @@ def getDatasetValueDialog(filename=None, message=None, parent=None):
     """
     hdf5Dialog = Hdf5SelectionDialog(parent, filename, message,
                                      "dataset")
-    ret = hdf5Dialog.exec_()
+    ret = hdf5Dialog.exec()
     if not ret:
         return None
 
@@ -1000,7 +1002,7 @@ def getDatasetValueDialog(filename=None, message=None, parent=None):
 def getDatasetUri(parent=None, filename=None, message=None):
     # TODO: Accept a filter for type of dataset
     hdf5Dialog = Hdf5SelectionDialog(parent, filename, message, "dataset")
-    ret = hdf5Dialog.exec_()
+    ret = hdf5Dialog.exec()
     if not ret:
         return None
     selectedHdf5Uri = hdf5Dialog.selectedItemUri
@@ -1009,7 +1011,7 @@ def getDatasetUri(parent=None, filename=None, message=None):
 def getGroupUri(parent=None, filename=None, message=None):
     # TODO: Accept a filter for a particular attribute (NXclass)
     hdf5Dialog = Hdf5SelectionDialog(parent, filename, message, "dataset")
-    ret = hdf5Dialog.exec_()
+    ret = hdf5Dialog.exec()
     if not ret:
         return None
     selectedHdf5Uri = hdf5Dialog.selectedItemUri
@@ -1017,7 +1019,7 @@ def getGroupUri(parent=None, filename=None, message=None):
 
 def getUri(parent=None, filename=None, message=None):
     hdf5Dialog = Hdf5SelectionDialog(parent, filename, message, "any")
-    ret = hdf5Dialog.exec_()
+    ret = hdf5Dialog.exec()
     if not ret:
         return None
     selectedHdf5Uri = hdf5Dialog.selectedItemUri
@@ -1031,7 +1033,7 @@ def getDatasetDialog(filename=None, value=False, message=None, parent=None):
                                      parent=parent)
 
     hdf5Dialog = Hdf5SelectionDialog(parent, filename, message, "dataset")
-    ret = hdf5Dialog.exec_()
+    ret = hdf5Dialog.exec()
     if not ret:
         return None
     selectedHdf5Uri = hdf5Dialog.selectedItemUri
@@ -1049,7 +1051,7 @@ def getGroupNameDialog(filename=None, message=None, parent=None):
     :return: HDF5 group name
     """
     hdf5Dialog = Hdf5SelectionDialog(parent, filename, message, "group")
-    ret = hdf5Dialog.exec_()
+    ret = hdf5Dialog.exec()
     if not ret:
         return None
 
@@ -1073,6 +1075,6 @@ if __name__ == "__main__":
             print(phynxFile[ddict['name']].dtype, phynxFile[ddict['name']].shape)
     fileView.sigHDF5WidgetSignal.connect(mySlot)
     fileView.show()
-    ret = app.exec_()
+    ret = app.exec()
     app = None
     sys.exit(ret)
