@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -87,7 +87,12 @@ class Buttons(qt.QWidget):
                 self.mainLayout.addWidget(button, row, col)
                 self.buttonGroup.addButton(button)
                 self.buttonList.append(button)
-        self.buttonGroup.buttonClicked[int].connect(self.emitSignal)
+        if hasattr(self.buttonGroup, "idClicked"):
+            self.buttonGroup.idClicked[int].connect(self.emitSignal)
+        else:
+            # deprecated
+            _logger.debug("Using deprecated signal")
+            self.buttonGroup.buttonClicked[int].connect(self.emitSignal)
 
     def emitSignal(self, idx):
         button = self.buttonGroup.button(idx)
@@ -124,6 +129,14 @@ class QNexusWidget(qt.QWidget):
         self._BUTTONS = buttons
         self.build()
 
+    def sizeHint(self):
+        originalHint = qt.QWidget.sizeHint(self)
+        if isinstance(self.parent(), qt.QDialog):
+            return qt.QSize(2 * originalHint.width(),
+                            originalHint.height())
+        else:
+            return qt.QSize(originalHint.width(),
+                            originalHint.height())
     def build(self):
         self.mainLayout = qt.QVBoxLayout(self)
         self.mainLayout.setContentsMargins(5, 5, 5, 0)
@@ -147,9 +160,8 @@ class QNexusWidget(qt.QWidget):
         #Enable 3D
         BUTTONS = self._BUTTONS
         if BUTTONS:
-            if ('PyMca.Object3D' in sys.modules) or \
-               ('Object3D' in sys.modules) or \
-               ('PyMca5.Object3D' in sys.modules):
+            if ('PyMca5.PyMcaGui.pymca.SilxGLWindow' in sys.modules) or \
+               ('PyMca5.PyMca.SilxGLWindow' in sys.modules):
                 self.buttons = Buttons(self, options=['SCAN', 'MCA', '2D', '3D'])
                 self.cntTable.set3DEnabled(True)
                 self.autoTable.set3DEnabled(True)
@@ -163,9 +175,8 @@ class QNexusWidget(qt.QWidget):
             self.mainLayout.addWidget(self.buttons)
         else:
             self.actions = QNexusWidgetActions.QNexusWidgetActions(self)
-            if ('PyMca.Object3D' in sys.modules) or \
-               ('Object3D' in sys.modules) or \
-               ('PyMca5.Object3D' in sys.modules):
+            if ('PyMca5.PyMcaGui.pymca.SilxGLWindow' in sys.modules) or \
+               ('PyMca5.PyMca.SilxGLWindow' in sys.modules):
                 self.actions.set3DEnabled(True)
             else:
                 self.actions.set3DEnabled(False)
@@ -226,14 +237,14 @@ class QNexusWidget(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Information)
             msg.setText("File does not contain HDF5 configuration")
-            msg.exec_()
+            msg.exec()
             return None
 
         if 'WidgetConfiguration' not in ddict['HDF5'].keys():
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Information)
             msg.setText("File does not contain HDF5 WidgetConfiguration")
-            msg.exec_()
+            msg.exec()
             return None
 
         ddict =ddict['HDF5']['WidgetConfiguration']
@@ -244,14 +255,14 @@ class QNexusWidget(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Information)
             msg.setText("File does not contain HDF5 counters information")
-            msg.exec_()
+            msg.exec()
             return None
 
         if len(ddict['counters']) != len(ddict['aliases']):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Number of counters does not match number of aliases")
-            msg.exec_()
+            msg.exec()
             return None
 
         return ddict
@@ -985,7 +996,16 @@ class QNexusWidget(qt.QWidget):
                     else:
                         actualDatasetPath = posixpath.join(entry,
                                                 cntSelection['cntlist'][yCnt])
-                    actualDataset = phynxFile[actualDatasetPath]
+                    try:
+                        actualDataset = phynxFile[actualDatasetPath]
+                    except KeyError:
+                        # filter x.1 and x.2 ESRF case
+                        if len(entryList) > 4:
+                            _logger.info("Ignoring %s in %s" % \
+                                         (actualDatasetPath, entry))
+                            continue
+                        else:
+                            raise
                     sel['scanselection'] = True
                     if hasattr(actualDataset, "shape"):
                         if len(actualDataset.shape) > 1:
@@ -1051,7 +1071,7 @@ class QNexusWidget(qt.QWidget):
                             msg = qt.QMessageBox(self)
                             msg.setIcon(qt.QMessageBox.Information)
                             msg.setText("Multidimensional data set as MCA. Using Average. You should use ROI Imaging")
-                            msg.exec_()
+                            msg.exec()
                             self._messageShown = True
                         sel['selection']['mcaselectiontype'] = "avg"
                 else:
@@ -1136,7 +1156,7 @@ if __name__ == "__main__":
     app = qt.QApplication(sys.argv)
     try:
         #this is to add the 3D buttons ...
-        from PyMca5 import Object3D
+        from PyMca5.PyMcaGui.pymca import SilxGLWindow
     except:
         pass
     w = QNexusWidget()
@@ -1156,5 +1176,5 @@ if __name__ == "__main__":
     w.sigAddSelection.connect(addSelection)
     w.sigRemoveSelection.connect(removeSelection)
     w.sigReplaceSelection.connect(replaceSelection)
-    ret = app.exec_()
+    ret = app.exec()
     sys.exit(ret)
