@@ -674,7 +674,7 @@ def test2():
     dialog.setParameters({'options': [1,3,5,7,9], 'method': 1, 'npc': 8,
                           'binning': 3})
     dialog.setModal(True)
-    ret = dialog.exec_()
+    ret = dialog.exec()
     if ret:
         dialog.close()
         print(dialog.getParameters())
@@ -696,7 +696,7 @@ def test():
         print(ddict['event'])
 
     container.sigMaskImageWidgetSignal.connect(theSlot)
-    app.exec_()
+    app.exec()
 
 if __name__ == "__main__":
     test()
