@@ -249,7 +249,7 @@ class SimpleFitGui(qt.QWidget):
             msg.setInformativeText("Function not imported %s" % \
                                            str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
         config = self.fitModule.getConfiguration()
         self.topWidget.setFunctions(config['fit']['functions'])
@@ -273,7 +273,7 @@ class SimpleFitGui(qt.QWidget):
             self._configurationDialog =\
                 SimpleFitConfigurationGui.SimpleFitConfigurationGui()
         self._configurationDialog.setSimpleFitInstance(self.fitModule)
-        if not self._configurationDialog.exec_():
+        if not self._configurationDialog.exec():
             _logger.debug("NOT UPDATING CONFIGURATION")
             oldConfig = self.fitModule.getConfiguration()
             self._configurationDialog.setConfiguration(oldConfig)
@@ -347,7 +347,7 @@ class SimpleFitGui(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText(text)
-            msg.exec_()
+            msg.exec()
             self.setStatus("Ready (after estimate error)")
 
     def setStatus(self, text=None):
@@ -369,7 +369,7 @@ class SimpleFitGui(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText(text)
-            msg.exec_()
+            msg.exec()
             self.setStatus("Ready (after fit error)")
             return
 
@@ -428,7 +428,7 @@ def test():
     #import DefaultFitFunctions as SpecfitFunctions
     from PyMca5.PyMca import SpecfitFunctions
     a=SpecfitFunctions.SpecfitFunctions()
-    x = numpy.arange(1000).astype(numpy.float)
+    x = numpy.arange(1000).astype(numpy.float64)
     p1 = numpy.array([1500,100.,50.0])
     p2 = numpy.array([1500,700.,50.0])
     y = a.gauss(p1, x)
@@ -457,4 +457,4 @@ if __name__=="__main__":
     _logger.setLevel(logging.DEBUG)
     app = qt.QApplication([])
     w = test()
-    app.exec_()
+    app.exec()
