@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2019 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V. Armando Sole - ESRF Data Analysis"
+__author__ = "V. Armando Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -158,7 +158,7 @@ class Concentrations(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("%s" % sys.exc_info()[1])
-            msg.exec_()
+            msg.exec()
 
     def closeEvent(self, event):
         qt.QWidget.closeEvent(self, event)
@@ -181,11 +181,11 @@ class Concentrations(qt.QWidget):
         layout.setContentsMargins(0, 0, 0, 0)
         layout.setSpacing(0)
         l1 = qt.QLabel(msg)
-        l1.setFixedWidth(l1.fontMetrics().width('##'))
+        l1.setFixedWidth(l1.fontMetrics().maxWidth()*len('##'))
         l2 = qt.QLabel(msg)
         l2.setText("%s" % message)
         l3 = qt.QLabel(msg)
-        l3.setFixedWidth(l3.fontMetrics().width('##'))
+        l3.setFixedWidth(l3.fontMetrics().maxWidth()*len('##'))
         layout.addWidget(l1)
         layout.addWidget(l2)
         layout.addWidget(l3)
@@ -286,8 +286,14 @@ class ConcentrationsWidget(qt.QWidget):
         #self.referenceCombo.insertItem('Auto')
         self.referenceLine = MyQLineEdit(wm)
         wm.layout.addWidget(self.referenceLine)
-        self.referenceLine.setFixedWidth(
-            self.referenceLine.fontMetrics().width('#######'))
+        fmetrics = self.referenceLine.fontMetrics()
+        fmtext = '#######'
+        if hasattr(fmetrics, "maxWidth"):
+            self.referenceLine.setFixedWidth(fmetrics.maxWidth()*len(fmtext))
+        else:
+            #deprecated
+            _logger.info("Using deprecated method")
+            self.referenceLine.setFixedWidth(fmetrics.width(fmtext))
 
         wm.layout.addWidget(qt.HorizontalSpacer(wm))
         self.referenceLine.sigMyQLineEditSignal.connect( \
@@ -420,7 +426,7 @@ class ConcentrationsWidget(qt.QWidget):
                 msg = qt.QMessageBox(self.referenceLine)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Element %s" % current)
-                msg.exec_()
+                msg.exec()
                 self.referenceLine.setFocus()
                 return
             if (current == '') or (current.upper() == 'AUTO'):
@@ -431,7 +437,7 @@ class ConcentrationsWidget(qt.QWidget):
                 msg = qt.QMessageBox(self.referenceLine)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Element %s" % current)
-                msg.exec_()
+                msg.exec()
                 self.referenceLine.setFocus()
             else:
                 self.referenceLine.setText(current)
@@ -481,7 +487,7 @@ class ConcentrationsWidget(qt.QWidget):
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Cannot use automatic concentrations time setting!!!")
-                msg.exec_()
+                msg.exec()
             else:
                 ddict['time'] = float(self._liveTime)
         else:
@@ -897,13 +903,13 @@ class MyQComboBox(qt.QComboBox):
                 msg = qt.QMessageBox(self._lineEdit)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Element %s" % current)
-                msg.exec_()
+                msg.exec()
                 self._lineEdit.setFocus()
             if not Elements.isValidFormula(current):
                 msg = qt.QMessageBox(self._lineEdit)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Element %s" % current)
-                msg.exec_()
+                msg.exec()
                 self._lineEdit.setFocus()
             else:
                 self.setCurrentText(current)
@@ -950,7 +956,7 @@ if __name__ == "__main__":
                 Elements.Material[material] = copy.deepcopy(d['result']['config']['materials'][material])
             demo.processFitResult(fitresult=d, elementsfrommatrix=False)
         demo.show()
-        ret = app.exec_()
+        ret = app.exec()
         app = None
         sys.exit(ret)
     else:
