@@ -253,7 +253,7 @@ class FitParamWidget(FitParamForm):
             text = "Error %s" % sys.exc_info()[1]
             msg.setInformativeText(text)
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def computeEfficiency(self):
         pars = self.__getAttPar()
@@ -285,11 +285,11 @@ class FitParamWidget(FitParamForm):
                 energies = numpy.arange(0.3, maxenergy, 0.1)
             else:
                 energies = numpy.arange(0.3, maxenergy, 0.02)
-        efficiency = numpy.ones(len(energies), numpy.float)
+        efficiency = numpy.ones(len(energies), numpy.float64)
         if (len(attenuators)+len(detector)+len(funnyfilters)) != 0:
             massatt = Elements.getMaterialMassAttenuationCoefficients
             if len(attenuators):
-                coeffs = numpy.zeros(len(energies), numpy.float)
+                coeffs = numpy.zeros(len(energies), numpy.float64)
                 for attenuator in attenuators:
                     formula   = attenuator[0]
                     thickness = attenuator[1] * attenuator[2]
@@ -298,7 +298,7 @@ class FitParamWidget(FitParamForm):
                 efficiency *= numpy.exp(-coeffs)
 
             if len(funnyfilters):
-                coeffs = numpy.zeros(len(energies), numpy.float)
+                coeffs = numpy.zeros(len(energies), numpy.float64)
                 funnyfactor = None
                 for attenuator in funnyfilters:
                     formula   = attenuator[0]
@@ -335,7 +335,7 @@ class FitParamWidget(FitParamForm):
                             xlabel='Energy (keV)',
                             ylabel='Efficiency Term',
                             replace=True)
-        self.graphDialog.exec_()
+        self.graphDialog.exec()
 
     def __contComboActivated(self, idx):
         if idx==4:
@@ -379,7 +379,7 @@ class FitParamWidget(FitParamForm):
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error configuring strategy")
                 msg.setInformativeText("You need to specify incident beam energy")
-                msg.exec_()
+                msg.exec()
         #_logger.debug("TO check for matrix composition")
         #_logger.debug("TO check for peaks")
 
@@ -392,7 +392,7 @@ class FitParamWidget(FitParamForm):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error configuring strategy")
             msg.setInformativeText("You need to specify incident beam energy")
-            msg.exec_()
+            msg.exec()
             return
         if self._strategyDialog is None:
             self._strategyDialog = StrategyHandler.StrategyHandlerDialog(self.parent())
@@ -412,10 +412,10 @@ class FitParamWidget(FitParamForm):
             msg.setText("Error configuring strategy")
             msg.setInformativeText(qt.safe_str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
             return
         self._strategyDialog.raise_()
-        ret = self._strategyDialog.exec_()
+        ret = self._strategyDialog.exec()
         if ret != qt.QDialog.Accepted:
             self._strategyDialog.setFitConfiguration(before)
 
@@ -429,11 +429,11 @@ class FitParamWidget(FitParamForm):
             msg.setWindowTitle("No data supplied")
             msg.setIcon(qt.QMessageBox.Information)
             msg.setText("Please enter the values in the fields")
-            msg.exec_()
+            msg.exec()
             return
 
         pars = self.__getFitPar()
-        y = numpy.ravel(numpy.array(self._counts)).astype(numpy.float)
+        y = numpy.ravel(numpy.array(self._counts)).astype(numpy.float64)
         x = numpy.ravel(numpy.array(self._channels))
         if self._stripDialog is None:
             self._stripDialog = StripBackgroundWidget.StripBackgroundDialog(self)
@@ -445,7 +445,7 @@ class FitParamWidget(FitParamForm):
 
         self._stripDialog.setParameters(pars)
         self._stripDialog.setData(x, y)
-        ret = self._stripDialog.exec_()
+        ret = self._stripDialog.exec()
         if not ret:
             return
         pars = self._stripDialog.getParameters()
@@ -1223,7 +1223,7 @@ class FitParamDialog(qt.QDialog):
             text = "Error %s" % sys.exc_info()[1]
             msg.setInformativeText(text)
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
             return 0
         self.setParameters(copy.deepcopy(cfg))
         return 1
@@ -1382,7 +1382,7 @@ class FitParamDialog(qt.QDialog):
 
 def openDialog():
     wid= FitParamDialog(modal=1)
-    ret = wid.exec_()
+    ret = wid.exec()
     if ret == qt.QDialog.Accepted:
         npar = wid.getParameters()
         print(npar)
