@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -202,13 +202,13 @@ class MaterialEditor(qt.QWidget):
                                 replace=True)
             self.graph.setGraphTitle(ddict['Comment'])
             if self.graphDialog is not None:
-                self.graphDialog.exec_()
+                self.graphDialog.exec()
         except:
             msg=qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def _massAttenuationSlot(self, ddict):
         try:
@@ -251,13 +251,13 @@ class MaterialEditor(qt.QWidget):
             self.graph.setActiveCurve(legend+' '+'Mass Att. (cm2/g)')
             self.graph.setGraphTitle(ddict['Comment'])
             if self.graphDialog is not None:
-                self.graphDialog.exec_()
+                self.graphDialog.exec()
         except:
             msg=qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def closeEvent(self, event):
         if self.graph is not None:
@@ -279,7 +279,10 @@ class MaterialComboBox(qt.QComboBox):
         self.setEditable(True)
         self._line = self.lineEdit()
         self.lastText = "_U_N1iKeLyText"
-        self.activated[str].connect(self._mySignal)
+        if hasattr(self, "textActivated"):
+            self.textActivated[str].connect(self._mySignal)
+        else:
+            self.activated[str].connect(self._mySignal)
         self._line.editingFinished.connect(self._mySlot)
 
     def setCurrentText(self, qstring):
@@ -309,14 +312,14 @@ class MaterialComboBox(qt.QComboBox):
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Material Name '%s'\n" % text + \
                             "It contains a % character.\n")
-                msg.exec_()
+                msg.exec()
                 msg = qt.QMessageBox.No
             elif text.endswith(" ") or text.startswith(" "):
                 msg =  qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Material Name '%s'\n" % text + \
                             "It starts or ends with a space character.\n")
-                msg.exec_()
+                msg.exec()
                 msg = qt.QMessageBox.No
             else:
                 try:
@@ -327,7 +330,7 @@ class MaterialComboBox(qt.QComboBox):
                     msg.setText("Invalid Material Name %s\n" % text + \
                                 "You cannot use a number as material name.\n" +\
                                 "Hint: You can use _%s_" % text)
-                    msg.exec_()
+                    msg.exec()
                     msg = qt.QMessageBox.No
                 except:
                     msg=qt.QMessageBox.information( self, "Invalid Material %s" % str(qstring),
@@ -353,7 +356,7 @@ class MaterialComboBox(qt.QComboBox):
             msg.setText("Invalid Material Name %s\n" % text + \
                         "The material is a valid Formula.\n " \
                         "There is no need to define it.")
-            msg.exec_()
+            msg.exec()
             self.setCurrentIndex(0)
             for i in range(self.count()):
                 selftext = self.itemText(i)
@@ -567,7 +570,7 @@ class MaterialGUI(qt.QWidget):
             nameHBoxLayout.addWidget(self.__nameLine)
             self.__nameLine.setReadOnly(False)
             longtext="En un lugar de La Mancha, de cuyo nombre no quiero acordarme ..."
-            self.__nameLine.setFixedWidth(self.__nameLine.fontMetrics().width(longtext))
+            self.__nameLine.setFixedWidth(self.__nameLine.fontMetrics().maxWidth()*len(longtext))
             layout.addWidget(nameHBox)
 
         self.__numberSpin.valueChanged[int].connect(self.__numberSpinChanged)
@@ -791,7 +794,7 @@ class MaterialGUI(qt.QWidget):
             msg=qt.QMessageBox(self.__densityLine)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Invalid Float")
-            msg.exec_()
+            msg.exec()
             self.__densityLine.setFocus()
 
     def __thicknessSlot(self, silent=False):
@@ -807,7 +810,7 @@ class MaterialGUI(qt.QWidget):
             msg=qt.QMessageBox(self.__thicknessLine)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Invalid Float")
-            msg.exec_()
+            msg.exec()
             self.__thicknessLine.setFocus()
 
     def __transmissionSlot(self):
@@ -892,7 +895,7 @@ class MaterialGUI(qt.QWidget):
                     msg=qt.QMessageBox(self.__table)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText("Invalid Formula %s" % compound)
-                    msg.exec_()
+                    msg.exec()
                     self.__table.setCurrentCell(row, col)
                     return
         else:
@@ -902,7 +905,7 @@ class MaterialGUI(qt.QWidget):
                 msg=qt.QMessageBox(self.__table)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Float")
-                msg.exec_()
+                msg.exec()
                 self.__table.setCurrentCell(row, col)
                 return
         self._updateCurrent()
@@ -945,7 +948,7 @@ class MaterialGUI(qt.QWidget):
                     msg=qt.QMessageBox(self.__table)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText("Invalid Formula %s" % compound)
-                    msg.exec_()
+                    msg.exec()
                     self.__table.setCurrentCell(self.__lastRow, self.__lastColumn)
                     return
         else:
@@ -955,7 +958,7 @@ class MaterialGUI(qt.QWidget):
                 msg=qt.QMessageBox(self.__table)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid Float")
-                msg.exec_()
+                msg.exec()
                 self.__table.setCurrentCell(self.__lastRow, self.__lastColumn)
                 return
         self._updateCurrent()
@@ -968,5 +971,5 @@ if __name__ == "__main__":
     else:
         demo = MaterialEditor(toolmode=False)
     demo.show()
-    ret  = app.exec_()
+    ret  = app.exec()
     app = None
