@@ -2,10 +2,10 @@
 #
 # The PyMca X-Ray Fluorescence Toolkit
 #
-# Copyright (c) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -26,7 +26,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V. Armando Sole - ESRF Data Analysis"
+__author__ = "V. Armando Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -541,7 +541,10 @@ class SimpleComboBox(qt.QComboBox):
         qt.QComboBox.__init__(self,parent)
         self.setEditable(False)
         self.setDuplicatesEnabled(False)
-        self.activated[str].connect(self._mySignal)
+        if hasattr(self, "textActivated"):
+            self.textActivated[str].connect(self._mySignal)
+        else:
+            self.activated[str].connect(self._mySignal)
 
     def setOptions(self, options):
         self.clear()
@@ -686,7 +689,7 @@ def main(fileName=None):
         d["SingleLayerStrategy"]["materials"] = "-", "Goethite", "-", "Goethite"
         d["SingleLayerStrategy"]["completer"] = "Mo"
         w.setFitConfiguration(d)
-    if w.exec_() == qt.QDialog.Accepted:
+    if w.exec() == qt.QDialog.Accepted:
         print(w.getParameters())
 
 
