@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2019 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -146,7 +146,12 @@ class ColormapDialog(qt.QDialog):
         hlayout0.addWidget(g2)
         hlayout0.addWidget(g3)
         vlayout.addWidget(hbox0)
-        self.buttonGroup.buttonClicked[int].connect(self.buttonGroupChange)
+        if hasattr(self.buttonGroup, "idClicked"):
+            self.buttonGroup.idClicked[int].connect(self.buttonGroupChange)
+        else:
+            # deprecated
+            _logger.debug("Using deprecated signal")
+            self.buttonGroup.buttonClicked[int].connect(self.buttonGroupChange)
         vlayout.addSpacing(20)
 
         hboxlimits = qt.QWidget(self)
@@ -614,7 +619,7 @@ def test():
 
     demo.setAutoscale(1)
     demo.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == "__main__":
