@@ -998,4 +998,4 @@ if __name__ == "__main__":
 
     mainWindow.show()
 
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
