@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -145,7 +145,13 @@ class PlotWindow(PlotWidget.PlotWidget):
             self._xPos = qt.QLineEdit(self.graphBottom)
             self._xPos.setText('------')
             self._xPos.setReadOnly(1)
-            self._xPos.setFixedWidth(self._xPos.fontMetrics().width('##############'))
+            fm = self._xPos.fontMetrics()
+            fmtext = '##############'
+            if hasattr(fm, "maxWidth"):
+                self._xPos.setFixedWidth(fm.maxWidth() * len(fmtext))
+            else:
+                _logger.debug("Using obsolete method")
+                self._xPos.setFixedWidth(fm.width(fmtext))
             self.graphBottomLayout.addWidget(self._xPos)
 
             label=qt.QLabel(self.graphBottom)
@@ -155,7 +161,13 @@ class PlotWindow(PlotWidget.PlotWidget):
             self._yPos = qt.QLineEdit(self.graphBottom)
             self._yPos.setText('------')
             self._yPos.setReadOnly(1)
-            self._yPos.setFixedWidth(self._yPos.fontMetrics().width('##############'))
+            fm = self._yPos.fontMetrics()
+            fmtext = '##############'
+            if hasattr(fm, "maxWidth"):
+                self._yPos.setFixedWidth(fm.maxWidth() * len(fmtext))
+            else:
+                _logger.debug("Using obsolete method")
+                self._yPos.setFixedWidth(fm.width(fmtext))
             self.graphBottomLayout.addWidget(self._yPos)
             self.graphBottomLayout.addWidget(qt.HorizontalSpacer(self.graphBottom))
         widget.layout().addWidget(self.graphBottom, 0)
@@ -416,9 +428,9 @@ class PlotWindow(PlotWidget.PlotWidget):
                                 self._averageIconSignal,
                                  'Average Plotted Curves')
 
-            tb = self._addToolButton(self.deriveIcon,
-                                self._deriveIconSignal,
-                                 'Take Derivative of Active Curve')
+            self.derivateToolButton = self._addToolButton(self.deriveIcon,
+                                            self._deriveIconSignal,
+                                            'Take Derivative of Active Curve')
 
             tb = self._addToolButton(self.smoothIcon,
                                  self._smoothIconSignal,
@@ -507,7 +519,7 @@ class PlotWindow(PlotWidget.PlotWidget):
         oldConfig = self.getPrintConfiguration()
         self._printConfigurationDialog.setPrintConfiguration(oldConfig,
                                                     printer=self._printer)
-        if self._printConfigurationDialog.exec_():
+        if self._printConfigurationDialog.exec():
             self.setPrintConfiguration(\
                 self._printConfigurationDialog.getPrintConfiguration())
 
@@ -954,7 +966,7 @@ class PlotWindow(PlotWidget.PlotWidget):
                 msg.setWindowTitle("No plugins")
                 msg.setInformativeText(" Problem loading plugins ")
                 msg.setDetailedText(message)
-                msg.exec_()
+                msg.exec()
             return
         if idx == 1:
             dirName = qt.safe_str(qt.QFileDialog.getExistingDirectory(self,
@@ -1010,7 +1022,7 @@ class PlotWindow(PlotWidget.PlotWidget):
             msg.setText("An error has occured while executing the plugin:")
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def _actionHovered(self, action):
         tip = action.toolTip()
@@ -1283,16 +1295,16 @@ class PlotWindow(PlotWidget.PlotWidget):
                 idx = nonzero((fromData <= xproc) &\
                                    (xproc <= toData))[0]
                 if len(idx):
-                    xw = xproc[idx].astype(numpy.float)
-                    yw = yproc[idx].astype(numpy.float)
-                    rawCounts = yw.sum(dtype=numpy.float)
+                    xw = xproc[idx].astype(numpy.float64)
+                    yw = yproc[idx].astype(numpy.float64)
+                    rawCounts = yw.sum(dtype=numpy.float64)
                     deltaX = xw[-1] - xw[0]
                     deltaY = yw[-1] - yw[0]
                     if deltaX > 0.0:
                         slope = (deltaY/deltaX)
                         background = yw[0] + slope * (xw - xw[0])
                         netCounts = rawCounts -\
-                                    background.sum(dtype=numpy.float)
+                                    background.sum(dtype=numpy.float64)
                     else:
                         netCounts = 0.0
                 else:
@@ -1349,7 +1361,7 @@ class PlotWindow(PlotWidget.PlotWidget):
             dialog = RenameCurveDialog.RenameCurveDialog(self,
                                                          oldLegend,
                                                          curveList)
-            ret = dialog.exec_()
+            ret = dialog.exec()
             if ret:
                 newLegend = dialog.getText()
                 self.renameCurve(oldLegend, newLegend, replot=True)
@@ -1497,7 +1509,7 @@ class PlotWindow(PlotWidget.PlotWidget):
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setInformativeText(str(sys.exc_info()[1]))
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
             return
         try:
             if sys.version_info.major >= 3:
@@ -1509,7 +1521,7 @@ class PlotWindow(PlotWidget.PlotWidget):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText("Input Output Error: %s" % (sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
             return
         try:
             if not len(self._curveList):
@@ -1517,7 +1529,7 @@ class PlotWindow(PlotWidget.PlotWidget):
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setInformativeText("No curve to be saved")
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
                 return
             activeCurve = self.getActiveCurve()
             if activeCurve is None:
@@ -1591,7 +1603,7 @@ class PlotWindow(PlotWidget.PlotWidget):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setInformativeText("Error while saving: %s" % (sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def _getOutputFileName(self):
         outfile = qt.QFileDialog(self)
@@ -1613,7 +1625,7 @@ class PlotWindow(PlotWidget.PlotWidget):
             outfile.setNameFilters(filterlist)
         outfile.setFileMode(outfile.AnyFile)
         outfile.setAcceptMode(outfile.AcceptSave)
-        ret = outfile.exec_()
+        ret = outfile.exec()
         if not ret:
             return None
         if hasattr(outfile, "selectedFilter"):
@@ -1682,5 +1694,5 @@ if __name__ == "__main__":
     #plot.removeCurve("dummy")
     #plot.addCurve(x, 2 * y, "dummy 2")
     #print("All curves = ",   plot.getAllCurves())
-    app.exec_()
+    app.exec()
     app = None
