@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -476,7 +476,7 @@ class McaBatchGUI(qt.QWidget):
                         button.clicked.connect(dialog.accept)
                         dialog.mainLayout.addWidget(nexusWidget)
                         dialog.mainLayout.addWidget(button)
-                        ret = dialog.exec_()
+                        ret = dialog.exec()
                         cntSelection = nexusWidget.cntTable.getCounterSelection()
                         cntlist = cntSelection['cntlist']
                         if not len(cntlist):
@@ -524,7 +524,7 @@ class McaBatchGUI(qt.QWidget):
         msg.setWindowTitle("PyMcaBatch Message")
         msg.setIcon(qt.QMessageBox.Information)
         msg.setText(text)
-        msg.exec_()
+        msg.exec()
 
     def setConfigFile(self,configfile=None):
         if configfile is None:return
@@ -1112,7 +1112,7 @@ class McaBatchGUI(qt.QWidget):
                 text = "Your batch has been started as an independent process."
                 msg.setText(text)
                 # REMARK: non-blocking for unit testing
-                #msg.exec_()
+                #msg.exec()
                 msg.show()
 
     def genListFile(self, listfile, config=None):
@@ -1606,7 +1606,7 @@ class McaBatchWindow(qt.QWidget):
                 if self.abortButton.text() == "OK":
                     # click for 100 milliseconds
                     _logger.debug("onEnd automatically clicking button")
-                    self.abortButton.animateClick(100)
+                    self.abortButton.animateClick()
         if self.exitonend:
             _logger.debug("onEnd close and not quit")
             self.close()
@@ -1787,7 +1787,7 @@ def main():
         w = McaBatchGUI(actions=1)
         w.show()
         w.raise_()
-        app.exec_()
+        app.exec()
     else:
         app.lastWindowClosed.connect(app.quit)
         text = "LegacyBatch from %s to %s" % (os.path.basename(filelist[0]), os.path.basename(filelist[-1]))
@@ -1811,7 +1811,7 @@ def main():
                 msg = qt.QMessageBox()
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("%s" % sys.exc_info()[1])
-                msg.exec_()
+                msg.exec()
                 return
 
 
@@ -1835,7 +1835,8 @@ def main():
         window._rootname = "%s"% b._rootname
         window.show()
         b.start()
-        app.exec_()
+        app.exec()
+    app = None
 
 if __name__ == "__main__":
     main()
