@@ -215,7 +215,7 @@ class Mca2EdfGUI(qt.QWidget):
                                        "All Files (*)"])
             filedialog.setModal(1)
             filedialog.setFileMode(filedialog.ExistingFiles)
-            ret = filedialog.exec_()
+            ret = filedialog.exec()
             if  ret == qt.QDialog.Accepted:
                 filelist0=filedialog.selectedFiles()
             else:
@@ -266,7 +266,7 @@ class Mca2EdfGUI(qt.QWidget):
             outfile.setModal(1)
             outfile.setDirectory(wdir)
             outfile.setFileMode(outfile.DirectoryOnly)
-            ret = outfile.exec_()
+            ret = outfile.exec()
         if ret:
             if QTVERSION < '4.0.0':
                 outdir = qt.safe_str(outfile.selectedFile())
@@ -360,12 +360,12 @@ class Mca2EdfBatch(qt.QThread):
                         if i == 0:
                             mcainfo,mcadata = ffile.LoadSource(key)
                         mcadata = scan_obj.mca(i+1)
-                        y0 = numpy.array(mcadata, numpy.float)
+                        y0 = numpy.array(mcadata, numpy.float64)
                         if counter == 0:
                             key0 = "%s key %s" % (os.path.basename(fitfile), key)
                             self.__ncols = len(y0)
                             image = numpy.zeros((self.__nrows,self.__ncols), \
-                                                numpy.float)
+                                                numpy.float64)
                         if self.__ncols !=  len(y0):
                             print("spectrum has different number of columns")
                             print("skipping it")
@@ -573,7 +573,7 @@ def main():
     if len(filelist) == 0:
         w = Mca2EdfGUI(actions=1)
         w.show()
-        sys.exit(app.exec_())
+        sys.exit(app.exec())
     else:
         text = "Batch from %s to %s" % (os.path.basename(filelist[0]), \
                                         os.path.basename(filelist[-1]))
@@ -598,7 +598,7 @@ def main():
         app.aboutToQuit.connect(cleanup)
         window.show()
         b.start()
-        sys.exit(app.exec_())
+        sys.exit(app.exec())
 
 if __name__ == "__main__":
     main()
