@@ -154,7 +154,7 @@ class McaWindow(ScanWindow):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Please Select an active curve")
             msg.setWindowTitle('MCA Window Simple Fit')
-            msg.exec_()
+            msg.exec()
             return
         x, y, info = self.getDataAndInfoFromLegend(legend)
         self.advancedfit.hide()
@@ -199,7 +199,7 @@ class McaWindow(ScanWindow):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error. Trying to fit fitted data?")
             msg.setWindowTitle('MCA Window Simple Fit')
-            msg.exec_()
+            msg.exec()
 
     def getActiveCurve(self, just_legend=False):
         _logger.debug("Local MCA window getActiveCurve called!!!!")
@@ -301,7 +301,7 @@ class McaWindow(ScanWindow):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Please Select an active curve")
             msg.setWindowTitle('MCA Window')
-            msg.exec_()
+            msg.exec()
             return
 
         x, y, info = self.getDataAndInfoFromLegend(legend)
@@ -342,7 +342,7 @@ class McaWindow(ScanWindow):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error. Trying to fit fitted data?")
-            msg.exec_()
+            msg.exec()
         return
 
     def __anasignal(self,dict):
@@ -358,7 +358,7 @@ class McaWindow(ScanWindow):
                     msg = qt.QMessageBox(self)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText("Please Select an active curve")
-                    msg.exec_()
+                    msg.exec()
                     return
                 else:
                     x, y, info = self.getDataAndInfoFromLegend(legend)
@@ -392,7 +392,7 @@ class McaWindow(ScanWindow):
                                                              caldict=ndict)
                     #info,x,y = self.getinfodatafromlegend(legend)
                     #caldialog.graph.newCurve("fromlegend",x=x,y=y)
-                    ret = caldialog.exec_()
+                    ret = caldialog.exec()
 
                     if ret == qt.QDialog.Accepted:
                         self.caldict.update(caldialog.getDict())
@@ -417,7 +417,7 @@ class McaWindow(ScanWindow):
                     msg = qt.QMessageBox(self)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText("Please Select an active curve")
-                    msg.exec_()
+                    msg.exec()
                     return
                 else:
                     x, y, info = self.getDataAndInfoFromLegend(legend)
@@ -482,7 +482,7 @@ class McaWindow(ScanWindow):
                                                         fl=0)
                     #info,x,y = self.getinfodatafromlegend(legend)
                     #caldialog.graph.newCurve("fromlegend",x=x,y=y)
-                    ret = caldialog.exec_()
+                    ret = caldialog.exec()
                     if ret == qt.QDialog.Accepted:
                         self.caldict.update(caldialog.getDict())
                         item, text = self.controlWidget.calbox.getCurrent()
@@ -508,7 +508,7 @@ class McaWindow(ScanWindow):
                     msg = qt.QMessageBox(self)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText(text)
-                    msg.exec_()
+                    msg.exec()
                     return
                 cald = ConfigDict.ConfigDict()
                 try:
@@ -518,7 +518,7 @@ class McaWindow(ScanWindow):
                     msg = qt.QMessageBox(self)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText(text)
-                    msg.exec_()
+                    msg.exec()
                     return
                 self.caldict.update(cald)
                 options = []
@@ -537,7 +537,7 @@ class McaWindow(ScanWindow):
                     msg = qt.QMessageBox(self)
                     msg.setIcon(qt.QMessageBox.Critical)
                     msg.setText(text)
-                    msg.exec_()
+                    msg.exec()
                     return
             elif dict['button'] == 'CalibrationSave':
                 filename = dict['line_edit']
@@ -550,7 +550,7 @@ class McaWindow(ScanWindow):
                         msg = qt.QMessageBox(self)
                         msg.setIcon(qt.QMessageBox.Critical)
                         msg.setText(text)
-                        msg.exec_()
+                        msg.exec()
                         return
                 cald.update(self.caldict)
                 cald.write(filename)
@@ -749,7 +749,7 @@ class McaWindow(ScanWindow):
             yb = numpy.array(ybfinal)
             newDataObject.x = [x]
             newDataObject.y = [yfit]
-            newDataObject.m = [numpy.ones(len(yfit)).astype(numpy.float)]
+            newDataObject.m = [numpy.ones(len(yfit)).astype(numpy.float64)]
             if mcamode:
                 newDataObject.info['regions']   = regions
                 newDataObject.info['baseline'] = yb
@@ -897,16 +897,16 @@ class McaWindow(ScanWindow):
                 if xhelp is None:
                     if 'Channel0' not in info:
                         info['Channel0'] = 0.0
-                    xhelp =info['Channel0'] + numpy.arange(len(data)).astype(numpy.float)
+                    xhelp =info['Channel0'] + numpy.arange(len(data)).astype(numpy.float64)
                     dataObject.x = [xhelp]
 
                 ylen = len(data)
                 if ylen == 1:
                     if len(xhelp) > 1:
-                        data = data[0] * numpy.ones(len(xhelp)).astype(numpy.float)
+                        data = data[0] * numpy.ones(len(xhelp)).astype(numpy.float64)
                         dataObject.y = [data]
                 elif len(xhelp) == 1:
-                    xhelp = xhelp[0] * numpy.ones(ylen).astype(numpy.float)
+                    xhelp = xhelp[0] * numpy.ones(ylen).astype(numpy.float64)
                     dataObject.x = [xhelp]
 
                 if not hasattr(dataObject, 'm'):
@@ -929,7 +929,7 @@ class McaWindow(ScanWindow):
                             mdata = numpy.take(mdata, index)
                             data = data/mdata
                             dataObject.x = [xhelp * 1]
-                            dataObject.m = [numpy.ones(len(data)).astype(numpy.float)]
+                            dataObject.m = [numpy.ones(len(data)).astype(numpy.float64)]
                         elif (len(mdata) == 1) or (ylen == 1):
                             if mdata[0] == 0.0:
                                 continue
@@ -1262,7 +1262,7 @@ class McaWindow(ScanWindow):
             yplot = ddict['yfit']
             newDataObject.x = [xplot]
             newDataObject.y = [yplot]
-            newDataObject.m = [numpy.ones(len(yplot)).astype(numpy.float)]
+            newDataObject.m = [numpy.ones(len(yplot)).astype(numpy.float64)]
 
             #here I should check the log or linear status
             self.dataObjectsDict[newDataObject.info['legend']] = newDataObject
@@ -1282,7 +1282,7 @@ class McaWindow(ScanWindow):
             yplot = self.scanFit.specfit.gendata(parameters=ddict['data'])
             newDataObject.x = [xplot]
             newDataObject.y = [yplot]
-            newDataObject.m = [numpy.ones(len(yplot)).astype(numpy.float)]
+            newDataObject.m = [numpy.ones(len(yplot)).astype(numpy.float64)]
 
             self.dataObjectsDict[newDataObject.info['legend']] = newDataObject
             self.addCurve(x=xplot, y=yplot,
@@ -1295,7 +1295,7 @@ class McaWindow(ScanWindow):
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Please Select an active curve")
             msg.setWindowTitle('MCA window')
-            msg.exec_()
+            msg.exec()
             return
         #get outputfile
         self.outputDir = PyMcaDirs.outputDir
@@ -1416,7 +1416,7 @@ class McaWindow(ScanWindow):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Input Output Error: %s" % (sys.exc_info()[1]))
-            msg.exec_()
+            msg.exec()
             return
         systemline = os.linesep
         os.linesep = '\n'
@@ -1444,7 +1444,7 @@ class McaWindow(ScanWindow):
                 msg.setInformativeText("Graphics Saving Error: %s" % \
                                        (sys.exc_info()[1]))
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
                 return
 
         try:
@@ -1456,7 +1456,7 @@ class McaWindow(ScanWindow):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Input Output Error: %s" % (sys.exc_info()[1]))
-            msg.exec_()
+            msg.exec()
             return
         systemline = os.linesep
         os.linesep = '\n'
@@ -1723,7 +1723,7 @@ def test():
     w.resetZoom()
     app.lastWindowClosed.connect(app.quit)
     w.show()
-    app.exec_()
+    app.exec()
 
 
 if __name__ == "__main__":
