@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -987,7 +987,7 @@ class McaBatchGUI(qt.QWidget):
         button.clicked.connect(dialog.accept)
         dialog.mainLayout.addWidget(nexusWidget)
         dialog.mainLayout.addWidget(button)
-        ret = dialog.exec_()
+        ret = dialog.exec()
         cntSelection = nexusWidget.cntTable.getCounterSelection()
         cntlist = cntSelection['cntlist']
         if not len(cntlist):
@@ -1000,7 +1000,9 @@ class McaBatchGUI(qt.QWidget):
             self.showMessage(text)
             self.__listView.clear()
             return selection
+        entryList = nexusWidget.getSelectedEntries()
         datasource = None
+        selection['entry'] = []
         selection['x'] = []
         selection['y'] = []
         selection['m'] = []
@@ -1008,6 +1010,8 @@ class McaBatchGUI(qt.QWidget):
             if len(cntSelection[key]):
                 for idx in cntSelection[key]:
                     selection[key].append(cntlist[idx])
+        for item in entryList:
+            selection['entry'].append(item[0])
         return selection
 
     def showMessage(self, text):
@@ -1015,7 +1019,7 @@ class McaBatchGUI(qt.QWidget):
         msg.setWindowTitle("PyMcaBatch Message")
         msg.setIcon(qt.QMessageBox.Information)
         msg.setText(text)
-        msg.exec_()
+        msg.exec()
 
     def setConfigFile(self,configfile=None):
         if configfile is None:
@@ -1094,6 +1098,22 @@ class McaBatchGUI(qt.QWidget):
                 else:
                     self.raise_()
                 return False
+        if len(self.fileList) == 1:
+            if HDF5SUPPORT:
+                try:
+                    if h5py.is_hdf5(self.fileList[0]):
+                        if os.path.dirname(os.path.abspath(self.fileList[0])) == \
+                           os.path.abspath(outputdir):
+                            msg = "Please specify a different output directory.\n"
+                            msg += "Risk of overwritting input file."
+                            qt.QMessageBox.critical(self,"ERROR", msg)
+                            if QTVERSION < '4.0.0':
+                                self.raiseW()
+                            else:
+                                self.raise_()
+                            return False
+                except:
+                    _logger.warning("Cannot verify suitability of output directory")
         return True
 
     def __getFileType(self,inputfile):
@@ -1463,7 +1483,7 @@ class McaBatchGUI(qt.QWidget):
             text = "Your fit has been started as an independent process."
             msg.setText(text)
             # REMARK: needs to be non-blocking for unit testing
-            #msg.exec_()
+            #msg.exec()
             msg.show()
 
     def genListFile(self, listfile, config=None):
@@ -1827,7 +1847,7 @@ class McaBatchWindow(qt.QWidget):
             except:
                 _logger.warning("ERROR on REPORT %s", sys.exc_info())
                 _logger.warning("%s", sys.exc_info()[1])
-                _logger.warning("filename = %s key =%s ", (filename, key))
+                _logger.warning("filename = %s key =%s " , filename, key)
                 _logger.warning("If your batch is stopped, please report this")
                 _logger.warning("error sending the above mentioned file and the")
                 _logger.warning("associated fit configuration file.")
@@ -1960,7 +1980,7 @@ class McaBatchWindow(qt.QWidget):
                 if self.abortButton.text() == "OK":
                     # click for 100 milliseconds
                     _logger.debug("onEnd automatically clicking button")
-                    self.abortButton.animateClick(100)
+                    self.abortButton.animateClick()
         if self.exitonend:
             _logger.debug("onEnd close and not quit")
             self.close()
@@ -2187,13 +2207,13 @@ def main():
                 msg = qt.QMessageBox()
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("%s" % sys.exc_info()[1])
-                msg.exec_()
+                msg.exec()
                 return
 
         window._rootname = "%s"% thread._rootname
         launchThread(thread, window)
-        
-    app.exec_()
+
+    app.exec()
     app = None
 
 if __name__ == "__main__":
