@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -91,24 +91,10 @@ if __name__ == '__main__':
             binding = arg.lower()
             if binding == "pyqt5":
                 import PyQt5.QtCore
-            elif binding == "pyqt4":
-                if sys.version_info < (3,):
-                    try:
-                        import sip
-                        sip.setapi('QString', 2)
-                        sip.setapi('QVariant', 2)
-                        sip.setapi('QDate', 2)
-                        sip.setapi('QDateTime', 2)
-                        sip.setapi('QTextStream', 2)
-                        sip.setapi('QTime', 2)
-                        sip.setapi('QUrl', 2)
-                    except:
-                        print("Cannot set sip API")
-                import PyQt4.QtCore
             elif binding == "pyside2":
                 import PySide2.QtCore
-            elif binding == "pyside":
-                import PySide.QtCore
+            elif binding == "pyside6":
+                import PySide6.QtCore
             else:
                 raise ValueError("Unknown Qt binding <%s>" % binding)
 
@@ -122,22 +108,14 @@ if __name__ == '__main__':
         if qtversion == '3':
             raise NotImplementedError("Qt3 is no longer supported")
         elif qtversion == '4':
-            if sys.version_info < (3,):
-                try:
-                    import sip
-                    sip.setapi('QString', 2)
-                    sip.setapi('QVariant', 2)
-                    sip.setapi('QDate', 2)
-                    sip.setapi('QDateTime', 2)
-                    sip.setapi('QTextStream', 2)
-                    sip.setapi('QTime', 2)
-                    sip.setapi('QUrl', 2)
-                except:
-                    print("Cannot set sip API")
-            import PyQt4.QtCore
+            raise NotImplementedError("Qt4 is no longer supported")
         elif qtversion == '5':
-            import PyQt5.QtCore
-
+            try:
+                import PyQt5.QtCore
+            except ImportError:
+                import PySide2.QtCore
+        elif qtversion == '6':
+            import PySide6.QtCore
     try:
         # make sure hdf5plugins are imported
         import hdf5plugin
@@ -153,10 +131,6 @@ if sys.platform == 'darwin':
                 print("Warning: OpenGL backend not fully supported")
 try:
     import silx
-    if (sys.version_info < (3,)) and ("PyQt4.QtCore" in sys.modules):
-        # PyQt4 is the most reliable binding at the ESRF for python 2
-        silxLogger = logging.getLogger("silx.DEPRECATION")
-        silxLogger.setLevel(logging.CRITICAL)
     # try to import silx prior to importing matplotlib to prevent
     # unnecessary warning
     import silx.gui.plot
@@ -247,11 +221,10 @@ try:
     #This is to make sure it is properly frozen
     #and that Object3D is fully supported
     import OpenGL.GL
-    #import Object3D.SceneGLWindow as SceneGLWindow
-    from PyMca5.PyMcaGui.pymca import PyMcaGLWindow
     OBJECT3D = False
     if ("PyQt4.QtOpenGL" in sys.modules) or \
        ("PySide.QtOpenGL") in sys.modules or \
+       ("PySide6.QtOpenGL") in sys.modules or \
        ("PySide2.QtOpenGL") in sys.modules or \
        ("PyQt5.QtOpenGL") in sys.modules:
         OBJECT3D = True
@@ -259,7 +232,6 @@ except:
     _logger.info("pyopengl not installed")
     OBJECT3D = False
 
-
 # Silx OpenGL availability (former Object3D)
 try:
     import PyMca5.PyMcaGui.pymca.SilxGLWindow
@@ -269,8 +241,8 @@ except ImportError:
 
 if isSilxGLAvailable:
     SceneGLWindow = PyMca5.PyMcaGui.pymca.SilxGLWindow
-elif OBJECT3D:
-    SceneGLWindow = PyMcaGLWindow
+else:
+    SceneGLWindow = None
 
 try:
     from PyMca5.PyMcaGui.pymca import SilxScatterWindow
@@ -302,6 +274,8 @@ if OPENGL_DRIVERS_OK and isSilxGLAvailable:
     except:
         _logger.info("Cannot test OpenGL availability %s" % sys.exc_info()[1])
 
+# PyMca 3D disabled in favor of silx
+OBJECT3D = isSilxGLAvailable
 _logger.info("SilxGL availability: %s", isSilxGLAvailable)
 
 from PyMca5.PyMcaGui.pymca import QDispatcher
@@ -339,7 +313,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 fl = qt.Qt.WA_DeleteOnClose
             PyMcaMdi.PyMcaMdi.__init__(self, parent, name, fl)
             maxheight = qt.QDesktopWidget().height()
-            if maxheight < 799:
+            if maxheight < 799 and maxheight > 0:
                 self.setMinimumHeight(int(0.8*maxheight))
                 self.setMaximumHeight(int(0.9*maxheight))
             self.setWindowTitle(name)
@@ -557,7 +531,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             msg.setText("Error: %s" % sys.exc_info()[1])
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def _dispatcherAddSelectionSlot(self, dictOrList):
         _logger.info("self._dispatcherAddSelectionSlot(ddict), ddict = %s",
@@ -686,7 +660,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             txt = "Error: %s" % sys.exc_info()[1]
             msg.setInformativeText(txt)
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def _dispatcherRemoveSelectionSlot(self, dictOrList):
         _logger.debug("self.dispatcherRemoveSelectionSlot(ddict), ddict = %s", dictOrList)
@@ -719,7 +693,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             txt = "Error: %s" % sys.exc_info()[1]
             msg.setInformativeText(txt)
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def _dispatcherReplaceSelectionSlot(self, dictOrList):
         _logger.debug("self.dispatcherReplaceSelectionSlot(ddict), ddict = %s",
@@ -983,7 +957,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                                 txt = "Error: %s\n opening file %s" % (sys.exc_info()[1],SourceName )
                                 msg.setInformativeText(txt)
                                 msg.setDetailedText(traceback.format_exc())
-                                msg.exec_()
+                                msg.exec()
 
                 if 'WidgetConfiguration' in ddict[source]:
                     selectorWidget = self.sourceWidget.selectorWidget[source]
@@ -996,7 +970,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                             txt = "Error: %s\n configuring %s widget" % (sys.exc_info()[1], source )
                             msg.setInformativeText(txt)
                             msg.setDetailedText(traceback.format_exc())
-                            msg.exec_()
+                            msg.exec()
         if "McaWindow" in ddict:
             self.mcaWindow.setCalibrations(ddict["McaWindow"]["calibrations"])
 
@@ -1366,7 +1340,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 txt = "This functionality requires tomogui, silx and FreeART"
                 msg.setInformativeText(txt)
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
                 return
             self.__reconsWidget = TomoguiProjectWindow()
         if self.__reconsWidget.isHidden():
@@ -1429,7 +1403,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 history = fdialog.history()
                 if len(history) > 6:
                     fdialog.setHistory(history[-6:])
-            ret = fdialog.exec_()
+            ret = fdialog.exec()
             if ret == qt.QDialog.Accepted:
                 filelist = fdialog.selectedFiles()
                 if getfilter:
@@ -1473,7 +1447,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 txt = "Input Output Error: %s" % (sys.exc_info()[1])
                 msg.setInformativeText(txt)
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
                 return
             except:
                 widget = None
@@ -1484,7 +1458,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 txt = "Error info = %s" % (sys.exc_info()[1])
                 msg.setInformativeText(txt)
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
                 return
         else:
             widget = self._widgetDict[self.__imagingTool]
@@ -1570,7 +1544,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
         if os.path.exists(self.configDir):
             cwd =self.configDir
         outfile.setDirectory(cwd)
-        ret = outfile.exec_()
+        ret = outfile.exec()
         if ret:
             if hasattr(outfile, "selectedFilter"):
                 filterused = qt.safe_str(outfile.selectedFilter()).split()
@@ -1607,7 +1581,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 txt = "Input Output Error: %s" % (sys.exc_info()[1])
                 msg.setInformativeText(txt)
                 msg.setDetailedText(traceback.format_exc())
-                msg.exec_()
+                msg.exec()
                 return
         try:
             self._saveAs(filename)
@@ -1616,7 +1590,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error Saving Configuration: %s" % (sys.exc_info()[1]))
-            msg.exec_()
+            msg.exec()
             return
 
     def _saveAs(self, filename=None):
@@ -1658,7 +1632,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
                 msg.setText("Cannot open data source")
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def openSource(self,index=0):
         _logger.debug("index = %d ", index)
@@ -1672,7 +1646,7 @@ class PyMcaMain(PyMcaMdi.PyMcaMdi):
             else:
                 outfile.setNameFilters(['PyMca  *.ini'])
             outfile.setFileMode(outfile.ExistingFile)
-            ret = outfile.exec_()
+            ret = outfile.exec()
             if ret:
                 filename = qt.safe_str(outfile.selectedFiles()[0])
                 outfile.close()
@@ -1931,14 +1905,14 @@ if __name__ == '__main__':
         msg.setText("Cannot open data source %s" % source)
         msg.setInformativeText(str(sys.exc_info()[1]))
         msg.setDetailedText(traceback.format_exc())
-        msg.exec_()
+        msg.exec()
 
     if PROFILING:
-        profile.run('sys.exit(app.exec_())',"test")
+        profile.run('sys.exit(app.exec())',"test")
         p=pstats.Stats("test")
         p.strip_dirs().sort_stats(-1).print_stats()
     else:
-        ret = app.exec_()
+        ret = app.exec()
         app = None
         sys.exit(ret)
 
