@@ -370,7 +370,7 @@ def test():
     w = QDispatcher()
     w.show()
     app.lastWindowClosed.connect(app.quit)
-    app.exec_()
+    app.exec()
 
 if __name__ == "__main__":
     test()
