@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2019 V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2021 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -43,6 +43,10 @@ if qt.BINDING in ["PyQt5", "PySide2"]:
     import matplotlib
     matplotlib.rcParams['backend']='Qt5Agg'
     from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
+elif qt.BINDING in ["PyQt6", "PySide6"]:
+    import matplotlib
+    matplotlib.rcParams['backend']='Qt5Agg'
+    from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 else:
     from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.figure import Figure
@@ -664,7 +668,7 @@ if __name__ == "__main__":
     w0.setXLabel('Channel')
     w0.setYLabel('Counts')
     w.plotLegends()
-    ret = w0.exec_()
+    ret = w0.exec()
     if ret:
         w.saveFile("filename.png")
         print("Plot filename.png saved")
@@ -676,4 +680,4 @@ if __name__ == "__main__":
     w.setXLabel('Channel')
     w.setYLabel('Counts')
     w.plotLegends()
-    ret = w0.exec_()
+    ret = w0.exec()
