@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -68,26 +68,12 @@ if __name__ == "__main__":
             binding = arg.lower()
             if binding == "pyqt5":
                 import PyQt5.QtCore
-            elif binding == "pyqt4":
-                if sys.version_info < (3,):
-                    try:
-                        import sip
-                        sip.setapi('QString', 2)
-                        sip.setapi('QVariant', 2)
-                        sip.setapi('QDate', 2)
-                        sip.setapi('QDateTime', 2)
-                        sip.setapi('QTextStream', 2)
-                        sip.setapi('QTime', 2)
-                        sip.setapi('QUrl', 2)
-                    except:
-                        print("Cannot set sip API")
-                import PyQt4.QtCore
             elif binding == "pyside2":
                 import PySide2.QtCore
-            elif binding == "pyside":
-                import PySide.QtCore
+            elif binding == "pyside6":
+                import PySide6.QtCore
             else:
-                raise ValueError("Unknown Qt binding <%s>" % binding)
+                raise ValueError("Unsupported Qt binding <%s>" % binding)
     from PyMca5.PyMcaCore.LoggingLevel import getLoggingLevel
     logging.basicConfig(level=getLoggingLevel(opts))
 
@@ -97,11 +83,6 @@ if hasattr(qt, "QString"):
 else:
     QString = qt.safe_str
 try:
-    if (sys.version_info < (3,)) and ("PyQt4.QtCore" in sys.modules):
-        # PyQt4 is the most reliable binding at the ESRF for python 2
-        import silx
-        silxLogger = logging.getLogger("silx.DEPRECATION")
-        silxLogger.setLevel(logging.CRITICAL)
     # try to import silx prior to importing matplotlib to prevent
     # unnecessary warning
     import silx.gui.plot
@@ -299,7 +280,7 @@ class QStackWidget(StackBase.StackBase,
             oldshape = self._stack.data.shape
             dialog = ImageShapeDialog(self, shape=oldshape[0:2])
             dialog.setModal(True)
-            ret = dialog.exec_()
+            ret = dialog.exec()
             if ret:
                 shape = dialog.getImageShape()
                 dialog.close()
@@ -381,7 +362,7 @@ class QStackWidget(StackBase.StackBase,
                 msg.setWindowTitle("Encoding error")
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Please use ASCII characters in file name and path")
-                msg.exec_()
+                msg.exec()
         return ""
 
     def _getOutputTiffFilename(self):
@@ -412,7 +393,7 @@ class QStackWidget(StackBase.StackBase,
                 msg.setWindowTitle("Encoding error")
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Please use ASCII characters in file name and path")
-                msg.exec_()
+                msg.exec()
         return ""
 
     def saveStackAsMonochromaticTiffImages(self, dtype=None):
@@ -552,7 +533,7 @@ class QStackWidget(StackBase.StackBase,
             msg.setText("An error has occured while saving the data:")
             msg.setInformativeText(qt.safe_str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def saveStackAsNeXusSpectra(self, compression=False):
         self.saveStackAsNeXus(interpretation="spectrum",
@@ -672,7 +653,7 @@ class QStackWidget(StackBase.StackBase,
                     msg.setText("An error has occurred while summing the master and slave stacks")
                     msg.setInformativeText(qt.safe_str(sys.exc_info()[1]))
                     msg.setDetailedText(traceback.format_exc())
-                    msg.exec_()
+                    msg.exec()
                 if "McaLiveTime" in masterStackDataObject.info:
                     try:
                         for slave in self._slaveList:
@@ -694,7 +675,7 @@ class QStackWidget(StackBase.StackBase,
                         msg.setText(txt)
                         msg.setInformativeText(qt.safe_str(sys.exc_info()[1]))
                         msg.setDetailedText(traceback.format_exc())
-                        msg.exec_()
+                        msg.exec()
                 self._closeSlave()
                 self.setStack(masterStackDataObject)
                 return
@@ -715,7 +696,7 @@ class QStackWidget(StackBase.StackBase,
             msg.setWindowTitle("Error loading slave stack")
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("%s: %s" % (sys.exc_info()[0], sys.exc_info()[1]))
-            msg.exec_()
+            msg.exec()
             return
         if stack is None:
             return
@@ -841,7 +822,7 @@ class QStackWidget(StackBase.StackBase,
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Information)
                 msg.setText("Problem loading plugins")
-                msg.exec_()
+                msg.exec()
             return
         if idx == 1:
             dirName = qt.safe_str(qt.QFileDialog.getExistingDirectory(self,
@@ -900,7 +881,7 @@ class QStackWidget(StackBase.StackBase,
             msg.setText("An error has occured while executing the plugin:")
             msg.setInformativeText(qt.safe_str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
             if _logger.getEffectiveLevel() == logging.DEBUG:
                 raise
 
@@ -1014,7 +995,7 @@ class QStackWidget(StackBase.StackBase,
         text = "Your data contain infinite values or nans.\n"
         text += "Pixels containing those values will be ignored."
         msg.setText(text)
-        msg.exec_()
+        msg.exec()
         return
 
     def calculateROIImages(self, index1, index2, imiddle=None, energy=None):
@@ -1027,7 +1008,7 @@ class QStackWidget(StackBase.StackBase,
             msg.setWindowTitle("No active curve selected")
             text = "Please select the MCA active curve."
             msg.setText(text)
-            msg.exec_()
+            msg.exec()
             return
         x, y, legend, info = activeCurve[:4]
         return StackBase.StackBase.calculateROIImages(self,
@@ -1177,6 +1158,11 @@ class QStackWidget(StackBase.StackBase,
             self.tab.setCurrentWidget(self.mcaWidget)
 
     def setSelectionMask(self, mask, instance_id=None):
+        if mask is not None:
+            if self._stackImageData is not None:
+                if mask.shape != self._stackImageData.shape:
+                    _logger.info("Reshaping mask")
+                    mask.shape = self._stackImageData.shape
         self._selectionMask = mask
         if instance_id == id(self):
             return
@@ -1293,7 +1279,7 @@ class QStackWidget(StackBase.StackBase,
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Please select an active curve")
-            msg.exec_()
+            msg.exec()
             return
         x, y, legend, info = self.mcaWidget.getActiveCurve()[:4]
         return x, y, legend, info
@@ -1337,8 +1323,8 @@ def test():
     nrows = 100
     ncols = 200
     nchannels = 1024
-    a = numpy.ones((nrows, ncols), numpy.float)
-    stackData = numpy.zeros((nrows, ncols, nchannels), numpy.float)
+    a = numpy.ones((nrows, ncols), numpy.float64)
+    stackData = numpy.zeros((nrows, ncols, nchannels), numpy.float64)
     for i in range(nchannels):
         stackData[:, :, i] = a * i
     stackData[0:10, :, :] = 0
@@ -1436,6 +1422,6 @@ if __name__ == "__main__":
     else:
         widget.setStack(stack)
     widget.show()
-    app.exec_()
+    app.exec()
     app = None
 
