@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2022 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -335,7 +335,12 @@ class RGBCorrelatorWidget(qt.QWidget):
 
         self.tableWidget.sigRGBCorrelatorTableSignal.connect(self._tableSlot)
 
-        self.buttonGroup.buttonClicked[int].connect(self._colormapTypeChange)
+        if hasattr(self.buttonGroup, "idClicked"):
+            self.buttonGroup.idClicked[int].connect(self._colormapTypeChange)
+        else:
+            # deprecated
+            _logger.debug("Using deprecated signal")
+            self.buttonGroup.buttonClicked[int].connect(self._colormapTypeChange)
 
     def _showCalculationDialog(self):
         if (not NNMA) and (not PCA) and (not KMEANS):
@@ -371,7 +376,7 @@ class RGBCorrelatorWidget(qt.QWidget):
 
         assert(TOMOGUI_FLAG is True)
         diag = TomoReconsDialog(entries=self._imageList)
-        if diag.exec_():
+        if diag.exec():
             if self._tomoguiWindow is None:
                 self._tomoguiWindow = TomoguiProjWindow()
 
@@ -439,21 +444,21 @@ class RGBCorrelatorWidget(qt.QWidget):
         if ddict['b'] == []:ddict['b'] = None
 
         if ddict['r'] is None:
-            self.__redImageData = numpy.zeros(self.__imageShape).astype(numpy.float)
+            self.__redImageData = numpy.zeros(self.__imageShape).astype(numpy.float64)
             self.__redLabel = None
         else:
             self.__redLabel = ddict['elementlist'][ddict['r'][0]]
             self.__redImageData = self._imageDict[self.__redLabel]['image']
 
         if ddict['g'] is None:
-            self.__greenImageData = numpy.zeros(self.__imageShape).astype(numpy.float)
+            self.__greenImageData = numpy.zeros(self.__imageShape).astype(numpy.float64)
             self.__greenLabel = None
         else:
             self.__greenLabel = ddict['elementlist'][ddict['g'][0]]
             self.__greenImageData = self._imageDict[self.__greenLabel]['image']
 
         if ddict['b'] is None:
-            self.__blueImageData = numpy.zeros(self.__imageShape).astype(numpy.float)
+            self.__blueImageData = numpy.zeros(self.__imageShape).astype(numpy.float64)
             self.__blueLabel = None
         else:
             self.__blueLabel = ddict['elementlist'][ddict['b'][0]]
@@ -591,7 +596,7 @@ class RGBCorrelatorWidget(qt.QWidget):
         return image_buffer, size, minmax
 
     def addImage(self, image0, label=None):
-        image = numpy.array(image0).astype(numpy.float)
+        image = numpy.array(image0).astype(numpy.float64)
         if label is None:
             label = "Unnamed 00"
             i = 0
@@ -704,7 +709,7 @@ class RGBCorrelatorWidget(qt.QWidget):
     def _imageResizeSlot(self):
         dialog = ImageShapeDialog(self, shape = self.__imageShape)
         dialog.setModal(True)
-        ret = dialog.exec_()
+        ret = dialog.exec()
         if ret:
             shape = dialog.getImageShape()
             dialog.close()
@@ -718,7 +723,7 @@ class RGBCorrelatorWidget(qt.QWidget):
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Error reshaping: %s" % sys.exc_info()[1])
-                msg.exec_()
+                msg.exec()
 
 
     def setImageShape(self, shape):
@@ -857,7 +862,7 @@ class RGBCorrelatorWidget(qt.QWidget):
             filedialog.setNameFilters(strlist)
             filedialog.selectNameFilter(self._saveFilter)
         filedialog.setDirectory(initdir)
-        ret = filedialog.exec_()
+        ret = filedialog.exec()
         if not ret: return ""
         filename = filedialog.selectedFiles()[0]
         if len(filename):
@@ -903,7 +908,7 @@ class RGBCorrelatorWidget(qt.QWidget):
         else:
             filedialog.setNameFilters(strlist)
         filedialog.setDirectory(initdir)
-        ret = filedialog.exec_()
+        ret = filedialog.exec()
         if not ret:
             if getfilter:
                 return [""], None
@@ -948,7 +953,7 @@ class RGBCorrelatorWidget(qt.QWidget):
             msg.setText("Error adding file: %s" % sys.exc_info()[1])
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
             if _logger.getEffectiveLevel() == logging.DEBUG:
                 raise
 
@@ -965,7 +970,7 @@ class RGBCorrelatorWidget(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("%s does not exist" % filename)
-            msg.exec_()
+            msg.exec()
             return
         if filterused is None:
             filterused = ''
@@ -1013,7 +1018,7 @@ class RGBCorrelatorWidget(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Cannot read file %s (h5py is missing)" % filename)
-            msg.exec_()
+            msg.exec()
             return
         # URI exists?
         if h5path:
@@ -1049,13 +1054,13 @@ class RGBCorrelatorWidget(qt.QWidget):
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("No (valid) datasets were found in '{}::{}'".format(filename, h5path))
-                msg.exec_()
+                msg.exec()
                 self._addHf5File(filename, ignoreStDev=ignoreStDev)
             elif len({dset.size for dset in datasets}) > 1:
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("'{}::{}' contains datasets with different sizes. Select datasets separately.".format(filename, h5path))
-                msg.exec_()
+                msg.exec()
                 self._addHf5File(filename, ignoreStDev=ignoreStDev)
             else:
                 for dset in datasets:
@@ -1070,7 +1075,7 @@ class RGBCorrelatorWidget(qt.QWidget):
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Cannot read file %s as an image" % filename)
-            msg.exec_()
+            msg.exec()
         else:
             #add as black and white
             self.addImage(makeQimageBW(qimage), os.path.basename(filename))
@@ -1090,7 +1095,7 @@ class RGBCorrelatorWidget(qt.QWidget):
                 #color image
                 colorIndex = 0
                 for component in ['R', 'G', 'B']:
-                    self.addImage(imgData[:,:,colorIndex].astype(numpy.float), title + '_' + component)
+                    self.addImage(imgData[:,:,colorIndex].astype(numpy.float64), title + '_' + component)
                     colorIndex += 1
                 data = imgData[:,:,0] * 0.114 +\
                         imgData[:,:,1] * 0.587 +\
@@ -1135,12 +1140,12 @@ class RGBCorrelatorWidget(qt.QWidget):
                     iterationList.append(i)
         else:
             iterationList = range(2, nlabels)
-        totalArray = numpy.zeros((nrows, nlabels), numpy.float)
+        totalArray = numpy.zeros((nrows, nlabels), numpy.float64)
         for i in range(nrows):
             totalArray[i, :] = [float(x) for x in lines[i+1].split()]
         nrows = int(max(totalArray[:,0]) + 1)
         ncols = int(max(totalArray[:,1]) + 1)
-        singleArray = numpy.zeros((nrows* ncols, 1), numpy.float)
+        singleArray = numpy.zeros((nrows* ncols, 1), numpy.float64)
         for i in iterationList:
             singleArray[:, 0] = totalArray[:,i] * 1
             self.addImage(numpy.resize(singleArray, (nrows, ncols)), labels[i])
@@ -1560,14 +1565,14 @@ class ImageShapeDialog(qt.QDialog):
                 msg = qt.QMessageBox(self)
                 msg.setIcon(qt.QMessageBox.Critical)
                 msg.setText("Invalid shape %d x %d" % (nrows, ncolumns))
-                msg.exec_()
+                msg.exec()
         except:
             self.rows.setText("%g" % self._shape[0])
             self.columns.setText("%g" % self._shape[1])
             msg = qt.QMessageBox(self)
             msg.setIcon(qt.QMessageBox.Critical)
             msg.setText("Error reshaping: %s" % sys.exc_info()[1])
-            msg.exec_()
+            msg.exec()
 
 
 class MyQLabel(qt.QLabel):
@@ -1644,7 +1649,7 @@ def main():
     #containerLayout.addWidget(w)
     #containerLayout.addWidget(graph)
     container.show()
-    app.exec_()
+    app.exec()
 
 if __name__ == "__main__":
     main()
