@@ -300,7 +300,7 @@ class StackROIBatchDialog(qt.QDialog):
 if __name__ == "__main__":
     app = qt.QApplication([])
     w = StackROIBatchDialog()
-    ret = w.exec_()
+    ret = w.exec()
     if ret:
         print(w.getParameters())
-    #app.exec_()
+    #app.exec()
