@@ -1,5 +1,5 @@
 #/*##########################################################################
-# Copyright (C) 2004-2019 T. Rueter, V.A. Sole, European Synchrotron Radiation Facility
+# Copyright (C) 2004-2020 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
 # the ESRF by the Software group.
@@ -136,7 +136,7 @@ import sys
 import traceback
 from PyMca5.PyMcaGui import PyMcaQt as qt
 from PyMca5 import PyMcaDataDir, PyMcaDirs
-from PyMca5.PyMcaGui import PyMcaFileDialogs
+from PyMca5.PyMcaGui.io import PyMcaFileDialogs
 from PyMca5.PyMcaIO import ConfigDict
 from PyMca5.PyMcaMath.fitting import SpecfitFunctions as SF
 from PyMca5.PyMcaMath import SNIPModule as snip
@@ -302,7 +302,7 @@ class AlignmentWidget(qt.QDialog):
             msg.setText("An error has occured while executing the plugin:")
             msg.setInformativeText(str(sys.exc_info()[1]))
             msg.setDetailedText(traceback.format_exc())
-            msg.exec_()
+            msg.exec()
 
     def store(self):
         self.done(self._storeCode)
@@ -327,7 +327,7 @@ class AlignmentWidget(qt.QDialog):
             msg = qt.QMessageBox()
             msg.setTitle('FFTAlignment Load Error')
             msg.setText('Unable to read shifts form file \'%s\''%filename)
-            msg.exec_()
+            msg.exec()
             return
         if 'Shifts' not in inDict.keys():
             # Only if the shift file consists exclusively of ShiftList
@@ -338,7 +338,7 @@ class AlignmentWidget(qt.QDialog):
                 msg = qt.QMessageBox()
                 msg.setWindowTitle('FFTAlignment Load Error')
                 msg.setText('No shift information found in file \'%s\''%filename)
-                msg.exec_()
+                msg.exec()
             ddict = dict(zip(orderedLegends, shiftList))
             llist = self.plugin.getOrder()
         else:
@@ -377,7 +377,7 @@ class AlignmentWidget(qt.QDialog):
             msg = qt.QMessageBox()
             msg.setWindowTitle('FFTAlignment Save Error')
             msg.setText('Unable to write configuration to \'%s\''%filename)
-            msg.exec_()
+            msg.exec()
         return True
 
     def getAlignmentMethodName(self):
@@ -651,7 +651,7 @@ class AdvancedAlignmentScanPlugin(Plugin1DBase.Plugin1DBase):
                 msg.setWindowTitle('Alignment Error')
                 msg.setText('Singular matrix encountered during least squares fit.')
                 msg.setStandardButtons(qt.QMessageBox.Ok)
-                msg.exec_()
+                msg.exec()
                 shift = float('NaN')
                 fitp, chisq, sigma = [None, None, None], 0., 0.
             key = legend
@@ -799,7 +799,7 @@ class AdvancedAlignmentScanPlugin(Plugin1DBase.Plugin1DBase):
             msg.setWindowTitle('Alignment Error')
             msg.setText('No shift data present.')
             msg.setStandardButtons(qt.QMessageBox.Ok)
-            msg.exec_()
+            msg.exec()
             return False
 
         # Check if interpolation is needed
@@ -818,7 +818,7 @@ class AdvancedAlignmentScanPlugin(Plugin1DBase.Plugin1DBase):
             msg.setStandardButtons(qt.QMessageBox.Ok | qt.QMessageBox.Cancel)
             msg.setDefaultButton(qt.QMessageBox.Ok)
 
-            if msg.exec_() != qt.QMessageBox.Ok:
+            if msg.exec() != qt.QMessageBox.Ok:
                 return False
 
         _logger.debug('applyShifts -- Shifting ...')
@@ -880,7 +880,7 @@ class AdvancedAlignmentScanPlugin(Plugin1DBase.Plugin1DBase):
         """
         # Empty shift table in the beginning
         widget = AlignmentWidget(None, self.shiftDict, self.shiftList, self)
-        ret = widget.exec_()
+        ret = widget.exec()
         if ret == 1:
             # Result code Apply
             self.shiftList, self.shiftDict = widget.getDict()
@@ -1004,7 +1004,7 @@ class AdvancedAlignmentScanPlugin(Plugin1DBase.Plugin1DBase):
         step = numpy.average(numpy.diff(activeX))
         xmin, xmax = self.getXLimits([x for (x,y,leg,info) in curves],
                                      overlap=False)
-        num  = factor * numpy.ceil((xmax-xmin)/step)
+        num  = int(factor * numpy.ceil((xmax-xmin)/step))
 
         # Create equidistant x-range, exclude first and last point
         xeq = numpy.linspace(xmin, xmax, num, endpoint=False)[:-1]
@@ -1151,7 +1151,7 @@ class AdvancedAlignmentScanPlugin(Plugin1DBase.Plugin1DBase):
             msg = qt.QMessageBox()
             msg.setWindowTitle('Alignment Scan Error')
             msg.setText('No help file found.')
-            msg.exec_()
+            msg.exec()
             _logger.debug('XMCDWindow -- init: Unable to read help file')
             self.helpFileBrowser = None
         if self.helpFileBrowser is not None:
@@ -1173,4 +1173,4 @@ if __name__ == "__main__":
     y1 = 1.0 + 50.0 * numpy.exp(-0.001*(x-500)**2) + 2.*numpy.random.random(250)
     y2 = 1.0 + 20.5 * numpy.exp(-0.005*(x-600)**2) + 2.*numpy.random.random(250)
 
-    app.exec_()
+    app.exec()
