@@ -176,7 +176,7 @@ class PCAStackPlugin(StackPluginBase.StackPluginBase):
         y = spectrum
         self.configurationWidget.setSpectrum(x, y, legend=legend, info=info)
         self.configurationWidget.show()
-        ret = self.configurationWidget.exec_()
+        ret = self.configurationWidget.exec()
         if ret:
             self._kMeansWidget = None
             self._executeFunctionAndParameters()
@@ -242,7 +242,7 @@ class PCAStackPlugin(StackPluginBase.StackPluginBase):
         else:
             stack = self.getStackDataObject()
             if isinstance(stack, numpy.ndarray):
-                if stack.data.dtype not in [numpy.float, numpy.float32]:
+                if stack.data.dtype not in [numpy.float64, numpy.float32]:
                     _logger.warning("WARNING: Non floating point data")
                     text = "Calculation going on."
                     text += " WARNING: Non floating point data."
